==> adx-common-2.7.11-sources.jar: com/bxm/adx/common/sell/init/UserInitializer.java <==
package com.bxm.adx.common.sell.init;

import com.bxm.adx.common.sell.BidRequest;
import com.bxm.adx.common.sell.position.Position;
import com.bxm.adx.common.sell.request.User;
import com.bxm.adx.common.sell.settings.MediaInstalledAppMapping;
import com.bxm.adx.common.sell.settings.MediaInstalledAppMappingCaching;
import com.google.common.collect.Lists;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.context.annotation.Configuration;

import java.util.List;
import java.util.Objects;

/**
 * @author fgf
 * @date 2024/12/24
 **/
@Configuration
public class UserInitializer implements BidRequestInitializer {

    private final MediaInstalledAppMappingCaching mediaInstalledAppMappingCaching;

    public UserInitializer(MediaInstalledAppMappingCaching mediaInstalledAppMappingCaching) {
        this.mediaInstalledAppMappingCaching = mediaInstalledAppMappingCaching;
    }

    @Override
    public void accept(BidRequest request, InitializerParam param) {
        User user = request.getUser();
        if (null == user) {
            return;
        }

        List<String> mappingList = getInstallList(user, param.getPosition());
        if (CollectionUtils.isNotEmpty(mappingList)) {
            user.setMapping_installed_app_list(mappingList);
        }
    }

    @Override
    public int getOrder() {
        return 0;
    }

    /**
     * 匹配映射值
     *
     * @param user
     * @return
     */
    private List<String> getInstallList(User user, Position position) {
        List<String> installList = Objects.isNull(user) ? null : user.getInstalled_app_list();
        if (CollectionUtils.isEmpty(installList)) {
            return null;
        }
        List<String> mappingList = Lists.newArrayListWithCapacity(installList.size());
        Long developerId = position.getDeveloperId();
        if (null != developerId) {
            installList.forEach(s -> {
                        MediaInstalledAppMapping mapping = mediaInstalledAppMappingCaching.get(developerId + ":" + s);
                        if (null != mapping) {
                            mappingList.add(mapping.getInstalledPackageName());
                        }
                    }
            );
        }
        return mappingList;
    }
}

==> adx-common-2.7.12-sources.jar: com/bxm/adx/common/sell/init/UserInitializer.java <==
package com.bxm.adx.common.sell.init;

import com.bxm.adx.common.sell.BidRequest;
import com.bxm.adx.common.sell.position.Position;
import com.bxm.adx.common.sell.request.User;
import com.bxm.adx.common.sell.settings.MediaInstalledAppMapping;
import com.bxm.adx.common.sell.settings.MediaInstalledAppMappingCaching;
import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.context.annotation.Configuration;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.stream.Collectors;

/**
 * @author fgf
 * @date 2024/12/24
 **/
@Configuration
public class UserInitializer implements BidRequestInitializer {

    private final MediaInstalledAppMappingCaching mediaInstalledAppMappingCaching;

    public UserInitializer(MediaInstalledAppMappingCaching mediaInstalledAppMappingCaching) {
        this.mediaInstalledAppMappingCaching = mediaInstalledAppMappingCaching;
    }

    @Override
    public void accept(BidRequest request, InitializerParam param) {
        User user = request.getUser();
        if (null == user) {
            return;
        }
        Map<String, String> installedAppMap = getMapping(user, param.getPosition());
        if (null != installedAppMap) {
            user.setInstalled_app_map(installedAppMap);
            List<String> mappingList = installedAppMap.values().stream().filter(Objects::nonNull).collect(Collectors.toList());
            if (CollectionUtils.isNotEmpty(mappingList)) {
                user.setMapping_installed_app_list(mappingList);
            }
        }
    }

    @Override
    public int getOrder() {
        return 0;
    }

    /**
     * 匹配映射值
     *
     * @param user
     * @return
     */
    private Map<String, String> getMapping(User user, Position position) {
        List<String> installList = Objects.isNull(user) ? null : user.getInstalled_app_list();
        if (CollectionUtils.isEmpty(installList)) {
            return null;
        }
        Map<String, String> installedAppMap = Maps.newHashMapWithExpectedSize(installList.size());
        Long developerId = position.getDeveloperId();
        if (null != developerId) {
            installList.forEach(s -> {
                        MediaInstalledAppMapping mapping = mediaInstalledAppMappingCaching.get(developerId + ":" + s);
                        if (null != mapping) {
                            installedAppMap.put(s, mapping.getInstalledPackageName());
                        } else {
                            installedAppMap.put(s, null);
                        }
                    }
            );
        }
        return installedAppMap;
    }
}
